diff mbox series

[v11,net-next,2/9] net: mdio: mscc-miim: add ability to be used in a non-mmio configuration

Message ID 20220628081709.829811-3-colin.foster@in-advantage.com
State New
Headers show
Series add support for VSC7512 control over SPI | expand

Commit Message

Colin Foster June 28, 2022, 8:17 a.m. UTC
There are a few Ocelot chips that contain the logic for this bus, but are
controlled externally. Specifically the VSC7511, 7512, 7513, and 7514. In
the externally controlled configurations these registers are not
memory-mapped.

Add support for these non-memory-mapped configurations.

Signed-off-by: Colin Foster <colin.foster@in-advantage.com>
---
 drivers/net/mdio/mdio-mscc-miim.c | 35 +++++++++++--------------------
 1 file changed, 12 insertions(+), 23 deletions(-)

Comments

Vladimir Oltean June 28, 2022, 4:26 p.m. UTC | #1
On Tue, Jun 28, 2022 at 01:17:02AM -0700, Colin Foster wrote:
> There are a few Ocelot chips that contain the logic for this bus, but are
> controlled externally. Specifically the VSC7511, 7512, 7513, and 7514. In
> the externally controlled configurations these registers are not
> memory-mapped.
> 
> Add support for these non-memory-mapped configurations.
> 
> Signed-off-by: Colin Foster <colin.foster@in-advantage.com>
> ---

These "add ability to be used in a non-MMIO configuration" commit
messages are very confusing when you are only adding support for
non-MMIO in ocelot_platform_init_regmap_from_resource() in patch 9/9.
May I suggest a reorder?
Colin Foster June 28, 2022, 6:31 p.m. UTC | #2
Hi Vladimir,

On Tue, Jun 28, 2022 at 04:26:05PM +0000, Vladimir Oltean wrote:
> On Tue, Jun 28, 2022 at 01:17:02AM -0700, Colin Foster wrote:
> > There are a few Ocelot chips that contain the logic for this bus, but are
> > controlled externally. Specifically the VSC7511, 7512, 7513, and 7514. In
> > the externally controlled configurations these registers are not
> > memory-mapped.
> > 
> > Add support for these non-memory-mapped configurations.
> > 
> > Signed-off-by: Colin Foster <colin.foster@in-advantage.com>
> > ---
> 
> These "add ability to be used in a non-MMIO configuration" commit
> messages are very confusing when you are only adding support for
> non-MMIO in ocelot_platform_init_regmap_from_resource() in patch 9/9.
> May I suggest a reorder?

Initially my plan was to get the MFD base functionality (SPI protocol,
chip reset, etc.) in and roll in each peripheral one at a time. That was
changed in v6 I believe...

Maybe a commit reword to suggest "utilize a helper function"?
diff mbox series

Patch

diff --git a/drivers/net/mdio/mdio-mscc-miim.c b/drivers/net/mdio/mdio-mscc-miim.c
index 08541007b18a..157c0b196eab 100644
--- a/drivers/net/mdio/mdio-mscc-miim.c
+++ b/drivers/net/mdio/mdio-mscc-miim.c
@@ -12,6 +12,7 @@ 
 #include <linux/iopoll.h>
 #include <linux/kernel.h>
 #include <linux/mdio/mdio-mscc-miim.h>
+#include <linux/mfd/ocelot.h>
 #include <linux/module.h>
 #include <linux/of_mdio.h>
 #include <linux/phy.h>
@@ -270,40 +271,27 @@  static int mscc_miim_clk_set(struct mii_bus *bus)
 
 static int mscc_miim_probe(struct platform_device *pdev)
 {
-	struct regmap *mii_regmap, *phy_regmap = NULL;
 	struct device_node *np = pdev->dev.of_node;
+	struct regmap *mii_regmap, *phy_regmap;
 	struct device *dev = &pdev->dev;
-	void __iomem *regs, *phy_regs;
 	struct mscc_miim_dev *miim;
-	struct resource *res;
 	struct mii_bus *bus;
 	int ret;
 
-	regs = devm_platform_get_and_ioremap_resource(pdev, 0, NULL);
-	if (IS_ERR(regs)) {
-		dev_err(dev, "Unable to map MIIM registers\n");
-		return PTR_ERR(regs);
-	}
-
-	mii_regmap = devm_regmap_init_mmio(dev, regs, &mscc_miim_regmap_config);
-
+	mii_regmap = ocelot_platform_init_regmap_from_resource(pdev, 0,
+						  &mscc_miim_regmap_config);
 	if (IS_ERR(mii_regmap)) {
 		dev_err(dev, "Unable to create MIIM regmap\n");
 		return PTR_ERR(mii_regmap);
 	}
 
-	/* This resource is optional */
-	res = platform_get_resource(pdev, IORESOURCE_MEM, 1);
-	if (res) {
-		phy_regs = devm_ioremap_resource(dev, res);
-		if (IS_ERR(phy_regs)) {
-			dev_err(dev, "Unable to map internal phy registers\n");
-			return PTR_ERR(phy_regs);
-		}
-
-		phy_regmap = devm_regmap_init_mmio(dev, phy_regs,
-						   &mscc_miim_phy_regmap_config);
-		if (IS_ERR(phy_regmap)) {
+	/* This resource is optional, so ENOENT can be ignored */
+	phy_regmap = ocelot_platform_init_regmap_from_resource(pdev, 1,
+						  &mscc_miim_phy_regmap_config);
+	if (IS_ERR(phy_regmap)) {
+		if (phy_regmap == ERR_PTR(-ENOENT)) {
+			phy_regmap = NULL;
+		} else {
 			dev_err(dev, "Unable to create phy register regmap\n");
 			return PTR_ERR(phy_regmap);
 		}
@@ -404,3 +392,4 @@  module_platform_driver(mscc_miim_driver);
 MODULE_DESCRIPTION("Microsemi MIIM driver");
 MODULE_AUTHOR("Alexandre Belloni <alexandre.belloni@bootlin.com>");
 MODULE_LICENSE("Dual MIT/GPL");
+MODULE_IMPORT_NS(MFD_OCELOT);